"""GPT-Terminal GPT Settings file."""

import openai
from config import OPENAI_KEY, MAX_TOKENS, GPT_MODEL
from checks import check_api, check_max_tokens, check_model

check_api(OPENAI_KEY)
check_model(GPT_MODEL)
check_max_tokens(MAX_TOKENS)

openai.api_key = OPENAI_KEY




def get_chatgpt_response(prompt):
    response = openai.ChatCompletion.create(
        model=GPT_MODEL,
        messages=[
            {"role": "system", "content": "You are a helpful assistant."},
            {"role": "user", "content": prompt}
        ],
        max_tokens=MAX_TOKENS
    )
    return response.choices[0].message['content']



"""GPT-Terminal configuration file."""

import platform

APP_NAME = "gpt-terminal"

OPENAI_KEY = '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'
MAX_TOKENS = 500
GPT_MODEL = 'gpt-3.5-turbo'


MODELS = {
    "gpt-3.5-turbo": 4097,
    "gpt-3.5-turbo-16k": 16385,
    "gpt-4": 8192,
    "gpt-4-32k": 32768,
}

MODELS_LIST = [
    "gpt-3.5-turbo",
    "gpt-3.5-turbo-16k",
    "gpt-4",
    "gpt-4-32k",
]

def machine_info():
    """Get the current machine info."""

    return platform.platform()

INIT_SYSTEM_MESSAGE = {
    "role": "system",
    "content": f"""
- Your name is "GPTerminal".
- You are a helpful personal assistant for programers.
- You are running on {machine_info()} machine.
- Please note that your answers will be displayed on the terminal.
- So keep answers short as possible and use a suitable format for printing on a terminal.
""",
}


INIT_WELCOME_MESSAGE = {
    "role": "system",
    "content": """
- Please start the conversation with a random and short greeting message starts with 'Welcome to GPTerminal'.
- Add a ton of self humor.
- Keep it short as possible, one line.
""",
}

INIT_WELCOME_BACK_MESSAGE = {
    "role": "system",
    "content": """
The conversation you remember was a while ago, now we are continuing it.
Please start the conversation with a random and short welcome back message.
- Start with 'Welcome back to GPTerminal'.
- Add a ton of self humor.
- Keep it short as possible, one line.

After the welcome back message, please summarize the last conversation. (e.g. "Last time we talked about ...")
- End with a something that invites the user to continue the conversation.
""",
}

TITLE_MESSAGE = """
Please give this conversation a short title.
I'm going to use this title as a file name for the conversation.
There are going to a lot of files like that under a folder "~/.gpterminal/conversations"
- Hard limit of 5 words.
- Use underscores instead of spaces.
- Don't mention yourself in it. (e.g. "GPTerminal conversation")
- Don't use any special characters.
- Don't use any numbers.
- Don't use any capital letters.
- Don't use any spaces.
- Don't use any punctuation.
- Don't use any symbols.
- Don't use any emojis.
- Don't use any accents.
- Don't use quotes.
- Don't use word like: "macos", "programmer_assistant", "conversation".
- Don't use any file extensions. (e.g. ".txt" or ".json")
"""


"""GPT-Terminal menu file."""

from config import MAX_TOKENS, OPENAI_KEY, GPT_MODEL


def get_menu():
    while True:
        welcome_to_menu_text = f"""

        Добро пожаловать в меню GPT-Terminal. 
        Вы можете настроить определенные параметры, написав число в консоль.
        (1): Настройка токена OpenAI API
        (2): Настройка модели GPT
        (3): Настройка MAX кол-ва токенов для запроса

        Текущие настройки:
        Ключ OpenAI API: {OPENAI_KEY}
        Модель GPT: {GPT_MODEL}
        MAX кол-во токенов на один запрос: {MAX_TOKENS}

        Чтобы выйти назад, напишите: chat
        Чтобы выйти из программы, напишите: exit
        """

        print(welcome_to_menu_text)

        user_input = input("Введите число или команду: ")

        if user_input.lower() == '1':
            print(f"Текущий Ключ OpenAI API: {OPENAI_KEY}")
            input_api = input("Введите новый Ключ OpenAI API: ")
            break
        if user_input.lower() == '2':
            print(f"Текущая Модель GPT: {GPT_MODEL}")
            input_model = input("Ввыберите другую модель: ")
            break
        if user_input.lower() == '3':
            print(f"Текущее MAX кол-во токенов на один запрос: {MAX_TOKENS}")
            input_max_tokens = int(input("Введите новое MAX кол-во токенов на один запрос: "))
            break

        
        if user_input.lower() == 'help':
            print(welcome_to_menu_text)
        if user_input.lower() == 'chat':
            print("В разработке...")
        if user_input.lower() == 'exit':
            break

        else:
            print('Такой команды или цифры нет. Попробуй сначала. Напиши help.')


def change_api():
    ...

def change_max_tokens():
    ...

def change_model():
    ...


"""GPT-Terminal main file."""
from gpt_settings import get_chatgpt_response
from menu import get_menu

def main():


    print("""
          Привет! Для выхода из программы введите 'exit'
          
          Напиши: 'menu', если хочешь зайти в настройки.
          """)
    while True:
        try:
            user_input = input("Вы: ")

            if user_input.lower() == 'exit':
                print("\nСпасибо за использование, возвращайтесь еще!")
                break

            if user_input.lower() == 'menu':
                get_menu()
                break

            response = get_chatgpt_response(user_input)
            print(f"ChatGPT: {response}")
        except Exception as e:
            print(e)
        except KeyboardInterrupt:
            print("\nСкрипт прерван пользователем.")
            break


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

def readme():
  with open('README.md', 'r') as f:
    return f.read()


setup(
    name='gpt-terminal',
    version='0.1.3',
    author='Plim4ik',
    author_email='quantumstack01@gmail.com',
    description='GPT-Terminal - power AI based system.',
    long_description=readme(),
    long_description_content_type='text/markdown',
    url='https://github.com/Plim4ik/GPTerminal',
    packages=find_packages(),
    install_requires=[
        'aiohttp==3.8.6',
        'aiosignal==1.3.1',
        'async-timeout==4.0.3',
        'attrs==23.1.0',
        'certifi==2023.7.22',
        'charset-normalizer==3.3.2',
        'frozenlist==1.4.0',
        'idna==3.4',
        'multidict==6.0.4',
        'openai==0.28.0',
        'requests==2.31.0',
        'tqdm==4.66.1',
        'urllib3==2.1.0',
        'yarl==1.9.2',
    ],
    
    entry_points={
        'console_scripts': [
            'gpt-terminal = gpt_terminal:main',
        ],
    },

    classifiers=[
    'Programming Language :: Python :: 3.11',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent'
    ],
    keywords='gpt terminal gpterminal openai',
    project_urls={
        'GitHub': 'https://github.com/Plim4ik/GPTerminal'
    },
    python_requires='>=3.8'
    )

